@@ -76,7 +76,6 @@ def get_hosts(request, tags=None, fields=None, *args, **kwargs):
         arguments.append('Filter: address ~~ %s' % i)
         arguments.append('Filter: plugin_output ~~ %s' % i)
         arguments.append('Or: 3')
-    print fields
     if fields is None:
         fields = [
             'name', 'plugin_output', 'last_check', 'state', 'services', 'services_with_info', 'services_with_state',
@@ -125,9 +124,8 @@ def get_hosts(request, tags=None, fields=None, *args, **kwargs):
             pass
 
     # Sort by host and service status
-    result.sort(reverse=True, cmp=lambda a, b:
-                cmp(a['num_problems'], b['num_problems']))
-    result.sort(reverse=True, cmp=lambda a, b: cmp(a['state'], b['state']))
+    result.sort(reverse=True, cmp=lambda a, b: cmp(a.get('num_problems'), b.get('num_problems')))
+    result.sort(reverse=True, cmp=lambda a, b: cmp(a.get('state'), b.get('state')))
     return result
 
 
