@@ -199,6 +199,25 @@ def services(request):
     c['services'] = utils.get_services(request, fields=fields, **request.GET)
     return render_to_response('status_services.html', c, context_instance=RequestContext(request))
 
+@error_handler
+def services_js(request):
+    """ This view handles list of services  """
+    c = {}
+    c['messages'] = []
+    c['errors'] = []
+    fields = [
+        'host_name', 'description', 'plugin_output', 'last_check', 'host_state', 'state',
+        'last_state_change', 'acknowledged', 'downtimes', 'host_downtimes', 'comments_with_info']
+    c['services'] = json.dumps(utils.get_services(request, fields=fields, **request.GET))
+    return render_to_response('status_services_js.html', c, context_instance=RequestContext(request))
+
+
+@error_handler
+def status_dt(request):
+    """ This view handles list of services  """
+    c = {}
+    return render_to_response('status_dt.html', c, context_instance=RequestContext(request))
+
 
 @error_handler
 def snippets_log(request):
@@ -1333,3 +1352,17 @@ def perfdata2(request):
     c['services'] = services
 
     return render_to_response('status_perfdata2.html', c, context_instance=RequestContext(request))
+
+
+def datatable(request, object_type):
+    """ Returns data (most often from livestatus) and returns in a datatable friendly format """
+    l = utils.livestatus(request)
+    hosts = l.get_hosts()
+    host = ['a','b']
+    result = {}
+    result['sEcho'] = 1
+    result['iTotalRecords'] = "1"
+    result['iTotalDisplayRecords'] = "1"
+    result['aaData'] = [host]
+    print "i am called"
+    return HttpResponse(str(result))
\ No newline at end of file
